# Generated by Django 5.0.2 on 2024-02-23 21:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_openpay", "0005_openpaycharge"),
    ]

    operations = [
        migrations.AlterField(
            model_name="openpaycharge",
            name="charge_id",
            field=models.CharField(
                help_text="Charge id", max_length=250, verbose_name="Charge id"
            ),
        ),
    ]
