# Generated by Django 5.0.2 on 2024-02-23 21:26

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_openpay", "0004_alter_openpaycard_other_data"),
    ]

    operations = [
        migrations.CreateModel(
            name="OpenpayCharge",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                (
                    "amount",
                    models.FloatField(
                        default=0,
                        help_text="Charge Amounts",
                        verbose_name="Charge Amount",
                    ),
                ),
                (
                    "charge_id",
                    models.FloatField(
                        default=0, help_text="Charge id", verbose_name="Charge id"
                    ),
                ),
                (
                    "authorization",
                    models.CharField(
                        help_text="Charge Authorizations",
                        max_length=250,
                        verbose_name="Charge Authorization",
                    ),
                ),
                (
                    "status",
                    models.CharField(
                        help_text="Charge Status",
                        max_length=250,
                        verbose_name="Charge Status",
                    ),
                ),
                (
                    "other_data",
                    models.JSONField(
                        blank=True, default=dict, help_text="Card Charge", null=True
                    ),
                ),
                (
                    "card",
                    models.ForeignKey(
                        help_text="Card Id",
                        on_delete=django.db.models.deletion.CASCADE,
                        to="artd_openpay.openpaycard",
                    ),
                ),
            ],
            options={
                "verbose_name": "Open Pay Charge",
                "verbose_name_plural": "Open Pay Charges",
            },
        ),
    ]
