# Generated by Django 5.0.2 on 2024-02-23 15:31

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("artd_partner", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="OpenPay",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("status", models.BooleanField(default=True, verbose_name="status")),
                (
                    "production_client_id",
                    models.CharField(
                        help_text="Production client id",
                        max_length=250,
                        verbose_name="Production client id",
                    ),
                ),
                (
                    "production_client_secret",
                    models.CharField(
                        help_text="Production client secret",
                        max_length=250,
                        verbose_name="Production client secret",
                    ),
                ),
                (
                    "production_public_key",
                    models.CharField(
                        help_text="Production public key",
                        max_length=250,
                        verbose_name="Production public key",
                    ),
                ),
                (
                    "Partner",
                    models.ForeignKey(
                        help_text="Partner",
                        on_delete=django.db.models.deletion.CASCADE,
                        to="artd_partner.partner",
                    ),
                ),
            ],
            options={
                "verbose_name": "OpenPay",
                "verbose_name_plural": "OpenPay",
            },
        ),
    ]
