# Generated by Django 5.0.2 on 2024-02-23 20:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_openpay", "0003_alter_openpay_options_openpaycard"),
    ]

    operations = [
        migrations.AlterField(
            model_name="openpaycard",
            name="other_data",
            field=models.JSONField(
                blank=True, default=dict, help_text="Card Type", null=True
            ),
        ),
    ]
