# Generated by Django 5.0.2 on 2024-02-23 16:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("artd_openpay", "0001_initial"),
    ]

    operations = [
        migrations.RenameField(
            model_name="openpay",
            old_name="Partner",
            new_name="partner",
        ),
    ]
