# Generated by Django 5.0.2 on 2024-02-23 19:53

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_customer", "0003_customer_external_id_customer_source_and_more"),
        ("artd_openpay", "0002_rename_partner_openpay_partner"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="openpay",
            options={"verbose_name": "Open Pay", "verbose_name_plural": "Open Pay"},
        ),
        migrations.CreateModel(
            name="OpenPayCard",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("status", models.BooleanField(default=True, verbose_name="status")),
                (
                    "bank_code",
                    models.CharField(
                        help_text="Bank Code", max_length=250, verbose_name="Bank Code"
                    ),
                ),
                (
                    "bank_name",
                    models.CharField(
                        help_text="Bank Name", max_length=250, verbose_name="Bank Name"
                    ),
                ),
                (
                    "brand",
                    models.CharField(
                        help_text="Brand", max_length=250, verbose_name="Brand"
                    ),
                ),
                (
                    "card_number",
                    models.CharField(
                        help_text="Card Number",
                        max_length=250,
                        verbose_name="Card Number",
                    ),
                ),
                (
                    "expiration_month",
                    models.CharField(
                        help_text="Expiration Month",
                        max_length=250,
                        verbose_name="Expiration Month",
                    ),
                ),
                (
                    "expiration_year",
                    models.CharField(
                        help_text="Expiration Year",
                        max_length=250,
                        verbose_name="Expiration Year",
                    ),
                ),
                (
                    "holder_name",
                    models.CharField(
                        help_text="Holder Name",
                        max_length=250,
                        verbose_name="Holder Name",
                    ),
                ),
                (
                    "card_id",
                    models.CharField(
                        help_text="Card Id", max_length=250, verbose_name="Card Id"
                    ),
                ),
                (
                    "card_type",
                    models.CharField(
                        help_text="Card Type", max_length=250, verbose_name="Card Type"
                    ),
                ),
                (
                    "other_data",
                    models.JSONField(
                        blank=True, default={}, help_text="Card Type", null=True
                    ),
                ),
                (
                    "customer",
                    models.ForeignKey(
                        help_text="Customer",
                        on_delete=django.db.models.deletion.CASCADE,
                        to="artd_customer.customer",
                    ),
                ),
            ],
            options={
                "verbose_name": "Open Pay Card",
                "verbose_name_plural": "Open Pay Cards",
            },
        ),
    ]
